@@ -81,7 +81,6 @@ class PClusterConfig(SlurmClusterConfig):
 
 
 class PClusterBackend(SlurmBackend):
-
     cluster_config_class = Type(
         "aws_pcluster_dask_gateway.aws_pcluster_dask_gateway.PClusterConfig",
         klass="dask_gateway_server.backends.base.ClusterConfig",
@@ -89,7 +88,6 @@ class PClusterBackend(SlurmBackend):
         config=True,
     )
 
-
     def get_submit_cmd_env_stdin(self, cluster, worker=None):
         cmd = [self.submit_command, "--parsable", "--job-name=dask-gateway"]
         if cluster.config.partition:
@@ -140,6 +138,7 @@ class PClusterBackend(SlurmBackend):
 
         return cmd, env, script
 
+
 # @dataclass
 # class DaskGatewayPClusterProfiles()
 # A mapping from profile name to configuration overrides
@@ -159,7 +158,7 @@ class PClusterBackend(SlurmBackend):
 def cluster_options(default_profile=None):
     dask_gateway_slurm_config = DaskGatewaySlurmConfig()
     profile_names = list(dask_gateway_slurm_config.profiles.keys())
-    if not default profile:
+    if not default_profile:
         default_profile = profile_names[0]
     elif default_profile and default_profile not in profile_names:
         default_profile = profile_names[0]
